@@ -3,7 +3,7 @@ package Role::TinyCommons::Collection::PickItems::RandomSeek;
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2021-05-03'; # DATE
 our $DIST = 'Role-TinyCommons-Collection'; # DIST
-our $VERSION = '0.004'; # VERSION
+our $VERSION = '0.005'; # VERSION
 
 # enabled by Role::Tiny
 #use strict;
@@ -50,14 +50,15 @@ Role::TinyCommons::Collection::PickItems::RandomSeek - Provide pick_items() that
 
 =head1 VERSION
 
-This document describes version 0.004 of Role::TinyCommons::Collection::PickItems::RandomSeek (from Perl distribution Role-TinyCommons-Collection), released on 2021-05-03.
+This document describes version 0.005 of Role::TinyCommons::Collection::PickItems::RandomSeek (from Perl distribution Role-TinyCommons-Collection), released on 2021-05-03.
 
 =head1 DESCRIPTION
 
 This role provides pick_items() that picks random items by random seeking. It is
-more suitable for huge collections that support C<get_item_at_pos> and an
-efficient C<get_item_count>. If your collection does not support those methods,
-there's an alternative can use L<Role::TinyCommons::FindItems::Iterator>.
+more suitable for huge collections that support C<get_item_at_pos> (see
+L<Role::TinyCommons::Collection::Position>) and an efficient C<get_item_count>.
+If your collection does not support those methods, there's an alternative you
+can use: L<Role::TinyCommons::FindItems::Iterator>.
 
 =for Pod::Coverage ^(.+)$
 
